"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["4919"],{73119(e,t,n){var r,i,u,a;function o(e,t,n){return function(r,i){for(;!r.eol();){if(r.match(t)){i.tokenize=f;break}r.next()}return n&&(i.tokenize=n),e}}function c(e){return function(t,n){for(;!t.eol();)t.next();return n.tokenize=f,e}}function f(e,t){function n(n){return t.tokenize=n,n(e,t)}var r=e.sol(),i=e.next();switch(i){case"{":return e.eat("/"),e.eatSpace(),e.eatWhile(/[^\s\u00a0=\"\'\/?(}]/),t.tokenize=s,"tag";case"_":if(e.eat("_"))return n(o("strong","__",f));break;case"'":if(e.eat("'"))return n(o("em","''",f));break;case"(":if(e.eat("("))return n(o("link","))",f));break;case"[":return n(o("url","]",f));case"|":if(e.eat("|"))return n(o("comment","||"));break;case"-":if(e.eat("="))return n(o("header string","=-",f));if(e.eat("-"))return n(o("error tw-deleted","--",f));break;case"=":if(e.match("=="))return n(o("tw-underline","===",f));break;case":":if(e.eat(":"))return n(o("comment","::"));break;case"^":return n(o("tw-box","^"));case"~":if(e.match("np~"))return n(o("meta","~/np~"))}if(r)switch(i){case"!":if(e.match("!!!!!"))return n(c("header string"));if(e.match("!!!!"))return n(c("header string"));if(e.match("!!!"))return n(c("header string"));else if(e.match("!!"))return n(c("header string"));else return n(c("header string"));case"*":case"#":case"+":return n(c("tw-listitem bracket"))}return null}function s(e,t){var n,r=e.next(),u=e.peek();if("}"==r)return t.tokenize=f,"tag";if("("==r||")"==r)return"bracket";if("="==r)return i="equals",">"==u&&(e.next(),u=e.peek()),/[\'\"]/.test(u)||(t.tokenize=function(e,t){for(;!e.eol();){var n=e.next(),r=e.peek();if(" "==n||","==n||/[ )}]/.test(r)){t.tokenize=s;break}}return"string"}),"operator";if(!/[\'\"]/.test(r))return e.eatWhile(/[^\s\u00a0=\"\'\/?]/),"keyword";return n=r,t.tokenize=function(e,t){for(;!e.eol();)if(e.next()==n){t.tokenize=s;break}return"string"},t.tokenize(e,t)}function l(){for(var e=arguments.length-1;e>=0;e--)u.cc.push(arguments[e])}function k(){return l.apply(null,arguments),!0}function d(e,t){var n=u.context&&u.context.noIndent;u.context={prev:u.context,pluginName:e,indent:u.indented,startOfLine:t,noIndent:n}}function g(){u.context&&(u.context=u.context.prev)}n.d(t,{tiki:()=>x});function p(e){return"keyword"==e?(a="attribute",k(p)):"equals"==e?k(m,p):l()}function m(e){return"keyword"==e?(a="string",k()):"string"==e?k(h):l()}function h(e){return"string"==e?k(h):l()}let x={name:"tiki",startState:function(){return{tokenize:f,cc:[],indented:0,startOfLine:!0,pluginName:null,context:null}},token:function(e,t){if(e.sol()&&(t.startOfLine=!0,t.indented=e.indentation()),e.eatSpace())return null;a=i=r=null;var n=t.tokenize(e,t);if((n||i)&&"comment"!=n)for(u=t;!(t.cc.pop()||function(e){if("openPlugin"==e){var t;return u.pluginName=r,k(p,(t=u.startOfLine,function(e){return"selfclosePlugin"==e||"endPlugin"==e||"endPlugin"==e&&d(u.pluginName,t),k()}))}if("closePlugin"==e){var n,i=!1;return u.context?(i=u.context.pluginName!=r,g()):i=!0,i&&(a="error"),k((n=i,function(e){return(n&&(a="error"),"endPlugin"==e)?k():l()}))}return"string"==e?(u.context&&"!cdata"==u.context.name||d("!cdata"),u.tokenize==f&&g(),k()):k()})(i||n););return t.startOfLine=!1,a||n},indent:function(e,t,n){var r=e.context;if(r&&r.noIndent)return 0;for(r&&/^{\//.test(t)&&(r=r.prev);r&&!r.startOfLine;)r=r.prev;return r?r.indent+n.unit:0}}}}]);