"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["5858"],{90137(n,e,t){t.d(e,{cmake:()=>r});var a=/({)?[a-zA-Z0-9_]+(})?/;function i(n,e){for(var t,a,i=!1;!n.eol()&&(t=n.next())!=e.pending;){if("$"===t&&"\\"!=a&&'"'==e.pending){i=!0;break}a=t}return i&&n.backUp(1),t==e.pending?e.continueString=!1:e.continueString=!0,"string"}let r={name:"cmake",startState:function(){var n={};return n.inDefinition=!1,n.inInclude=!1,n.continueString=!1,n.pending=!1,n},token:function(n,e){if(n.eatSpace())return null;var t=n.next();return"$"===t?n.match(a)?"variableName.special":"variable":e.continueString?(n.backUp(1),i(n,e)):n.match(/(\s+)?\w+\(/)||n.match(/(\s+)?\w+\ \(/)?(n.backUp(1),"def"):"#"==t?(n.skipToEnd(),"comment"):"'"==t||'"'==t?(e.pending=t,i(n,e)):"("==t||")"==t?"bracket":t.match(/[0-9]/)?"number":(n.eatWhile(/[\w-]/),null)}}}}]);