(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["142"],{99105(t,e,o){var r,n=1/0,c=/[&<>"'`]/g,l=RegExp(c.source),u="object"==typeof o.g&&o.g&&o.g.Object===Object&&o.g,f="object"==typeof self&&self&&self.Object===Object&&self,p=u||f||Function("return this")(),b=(r={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","`":"&#96;"},function(t){return null==r?void 0:r[t]}),i=Object.prototype.toString,s=p.Symbol,g=s?s.prototype:void 0,y=g?g.toString:void 0;t.exports=function(t){var e;return(t=null==(e=t)?"":function(t){if("string"==typeof t)return t;if(function(t){return"symbol"==typeof t||!!t&&"object"==typeof t&&"[object Symbol]"==i.call(t)}(t))return y?y.call(t):"";var e=t+"";return"0"==e&&1/t==-n?"-0":e}(e))&&l.test(t)?t.replace(c,b):t}}}]);