"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["256"],{12787(t,e,n){function r(){return{mangle:!1,walkTokens(t){if("link"!==t.type||!t.href.startsWith("mailto:"))return;let e=t.href.substring(7),n=function(t){let e="",n,r,s=t.length;for(n=0;n<s;n++)r=t.charCodeAt(n),Math.random()>.5&&(r="x"+r.toString(16)),e+="&#"+r+";";return e}(e);t.href=`mailto:${n}`,1===t.tokens.length&&"text"===t.tokens[0].type&&t.tokens[0].text===e&&(t.text=n,t.tokens[0].text=n)}}}n.r(e),n.d(e,{mangle:()=>r})}}]);