"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["5888"],{89331(e,c,r){r.d(c,{createArchitectureServices:()=>s.S});var s=r(76644);r(51526)}}]);