"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["5253"],{78868(e,t,n){n.d(t,{solr:()=>a});var r=/[^\s\|\!\+\-\*\?\~\^\&\:\(\)\[\]\{\}\"\\]/,o=/[\|\!\+\-\*\?\~\^\&]/,u=/^(OR|AND|NOT|TO)$/;function i(e,t){var n,a=e.next();return'"'==a?t.tokenize=function(e,t){for(var n,r=!1;null!=(n=e.next())&&(n!=a||r);)r=!r&&"\\"==n;return r||(t.tokenize=i),"string"}:o.test(a)?t.tokenize=function(e,t){return"|"==a?e.eat(/\|/):"&"==a&&e.eat(/\&/),t.tokenize=i,"operator"}:r.test(a)&&(n=a,t.tokenize=function(e,t){for(var o,a=n;(n=e.peek())&&null!=n.match(r);)a+=e.next();return(t.tokenize=i,u.test(a))?"operator":parseFloat(o=a).toString()===o?"number":":"==e.peek()?"propertyName":"string"}),t.tokenize!=i?t.tokenize(e,t):null}let a={name:"solr",startState:function(){return{tokenize:i}},token:function(e,t){return e.eatSpace()?null:t.tokenize(e,t)}}}}]);