"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["6391"],{20634(e,n,t){t.d(n,{dockerFile:()=>k});var r=t(84832),a="from",o=RegExp("^(\\s*)\\b("+a+")\\b","i"),s=["run","cmd","entrypoint","shell"],l=RegExp("^(\\s*)("+s.join("|")+")(\\s+\\[)","i"),i="expose",g=RegExp("^(\\s*)("+i+")(\\s+)","i"),u="("+[a,i].concat(s).concat(["arg","from","maintainer","label","env","add","copy","volume","user","workdir","onbuild","stopsignal","healthcheck","shell"]).join("|")+")",d=RegExp("^(\\s*)"+u+"(\\s*)(#.*)?$","i"),x=RegExp("^(\\s*)"+u+"(\\s+)","i");let k=(0,r.I)({start:[{regex:/^\s*#.*$/,sol:!0,token:"comment"},{regex:o,token:[null,"keyword"],sol:!0,next:"from"},{regex:d,token:[null,"keyword",null,"error"],sol:!0},{regex:l,token:[null,"keyword",null],sol:!0,next:"array"},{regex:g,token:[null,"keyword",null],sol:!0,next:"expose"},{regex:x,token:[null,"keyword",null],sol:!0,next:"arguments"},{regex:/./,token:null}],from:[{regex:/\s*$/,token:null,next:"start"},{regex:/(\s*)(#.*)$/,token:[null,"error"],next:"start"},{regex:/(\s*\S+\s+)(as)/i,token:[null,"keyword"],next:"start"},{token:null,next:"start"}],single:[{regex:/(?:[^\\']|\\.)/,token:"string"},{regex:/'/,token:"string",pop:!0}],double:[{regex:/(?:[^\\"]|\\.)/,token:"string"},{regex:/"/,token:"string",pop:!0}],array:[{regex:/\]/,token:null,next:"start"},{regex:/"(?:[^\\"]|\\.)*"?/,token:"string"}],expose:[{regex:/\d+$/,token:"number",next:"start"},{regex:/[^\d]+$/,token:null,next:"start"},{regex:/\d+/,token:"number"},{regex:/[^\d]+/,token:null},{token:null,next:"start"}],arguments:[{regex:/^\s*#.*$/,sol:!0,token:"comment"},{regex:/"(?:[^\\"]|\\.)*"?$/,token:"string",next:"start"},{regex:/"/,token:"string",push:"double"},{regex:/'(?:[^\\']|\\.)*'?$/,token:"string",next:"start"},{regex:/'/,token:"string",push:"single"},{regex:/[^#"']+[\\`]$/,token:null},{regex:/[^#"']+$/,token:null,next:"start"},{regex:/[^#"']+/,token:null},{token:null,next:"start"}],languageData:{commentTokens:{line:"#"}}})},84832(e,n,t){function r(e){a(e,"start");var n,t,r,s={},l=e.languageData||{},i=!1;for(var g in e)if(g!=l&&e.hasOwnProperty(g))for(var u=s[g]=[],d=e[g],x=0;x<d.length;x++){var k=d[x];u.push(new o(k,e)),(k.indent||k.dedent)&&(i=!0)}return{name:l.name,startState:function(){return{state:"start",pending:null,indent:i?[]:null}},copyState:function(e){var n={state:e.state,pending:e.pending,indent:e.indent&&e.indent.slice(0)};return e.stack&&(n.stack=e.stack.slice(0)),n},token:(n=s,function(e,t){if(t.pending){var r=t.pending.shift();return 0==t.pending.length&&(t.pending=null),e.pos+=r.text.length,r.token}for(var a=n[t.state],o=0;o<a.length;o++){var s=a[o],l=(!s.data.sol||e.sol())&&e.match(s.regex);if(l){s.data.next?t.state=s.data.next:s.data.push?((t.stack||(t.stack=[])).push(t.state),t.state=s.data.push):s.data.pop&&t.stack&&t.stack.length&&(t.state=t.stack.pop()),s.data.indent&&t.indent.push(e.indentation()+e.indentUnit),s.data.dedent&&t.indent.pop();var i=s.token;if(i&&i.apply&&(i=i(l)),l.length>2&&s.token&&"string"!=typeof s.token){t.pending=[];for(var g=2;g<l.length;g++)l[g]&&t.pending.push({text:l[g],token:s.token[g-1]});return e.backUp(l[0].length-(l[1]?l[1].length:0)),i[0]}if(i&&i.join)return i[0];return i}}return e.next(),null}),indent:(t=s,r=l,function(e,n){if(null==e.indent||r.dontIndentStates&&r.dontIndentStates.indexOf(e.state)>-1)return null;var a=e.indent.length-1,o=t[e.state];e:for(;;){for(var s=0;s<o.length;s++){var l=o[s];if(l.data.dedent&&!1!==l.data.dedentIfLineStart){var i=l.regex.exec(n);if(i&&i[0]){a--,(l.next||l.push)&&(o=t[l.next||l.push]),n=n.slice(i[0].length);continue e}}}break}return a<0?0:e.indent[a]}),mergeTokens:l.mergeTokens,languageData:l}}function a(e,n){if(!e.hasOwnProperty(n))throw Error("Undefined state "+n+" in simple mode")}function o(e,n){(e.next||e.push)&&a(n,e.next||e.push),this.regex=function(e){if(!e)return/(?:)/;var n="";return e instanceof RegExp?(e.ignoreCase&&(n="i"),e.unicode&&(n+="u"),e=e.source):e=String(e),RegExp("^(?:"+e+")",n)}(e.regex),this.token=function(e){if(!e)return null;if(e.apply)return e;if("string"==typeof e)return e.replace(/\./g," ");for(var n=[],t=0;t<e.length;t++)n.push(e[t]&&e[t].replace(/\./g," "));return n}(e.token),this.data=e}t.d(n,{I:()=>r})}}]);