"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["1921"],{93720(e,t,n){n.d(t,{toml:()=>r});let r={name:"toml",startState:function(){return{inString:!1,stringType:"",lhs:!0,inArray:0}},token:function(e,t){let n;if(!t.inString&&(n=e.match(/^('''|"""|'|")/))&&(t.stringType=n[0],t.inString=!0),e.sol()&&!t.inString&&0===t.inArray&&(t.lhs=!0),t.inString){for(;t.inString;)if(e.match(t.stringType))t.inString=!1;else if("\\"===e.peek())e.next(),e.next();else if(e.eol())break;else e.match(/^.[^\\\"\']*/);return t.lhs?"property":"string"}if(t.inArray&&"]"===e.peek())return e.next(),t.inArray--,"bracket";if(t.lhs&&"["===e.peek()&&e.skipTo("]"))return e.next(),"]"===e.peek()&&e.next(),"atom";if("#"===e.peek())return e.skipToEnd(),"comment";if(e.eatSpace());else if(t.lhs&&e.eatWhile(function(e){return"="!=e&&" "!=e}))return"property";else if(t.lhs&&"="===e.peek())e.next(),t.lhs=!1;else{if(!t.lhs&&e.match(/^\d\d\d\d[\d\-\:\.T]*Z/)||!t.lhs&&(e.match("true")||e.match("false")))return"atom";if(!t.lhs&&"["===e.peek())return t.inArray++,e.next(),"bracket";if(!t.lhs&&e.match(/^\-?\d+(?:\.\d+)?/))return"number";e.eatSpace()||e.next()}return null},languageData:{commentTokens:{line:"#"}}}}}]);