"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["390"],{45637(e,n,t){t.d(n,{brainfuck:()=>i});var r="><+-.,[]".split("");let i={name:"brainfuck",startState:function(){return{commentLine:!1,left:0,right:0,commentLoop:!1}},token:function(e,n){if(e.eatSpace())return null;e.sol()&&(n.commentLine=!1);var t=e.next().toString();if(-1===r.indexOf(t))return n.commentLine=!0,e.eol()&&(n.commentLine=!1),"comment";if(!0===n.commentLine)return e.eol()&&(n.commentLine=!1),"comment";if("]"===t||"["===t)return"["===t?n.left++:n.right++,"bracket";if("+"===t||"-"===t)return"keyword";if("<"===t||">"===t)return"atom";if("."===t||","===t)return"def";e.eol()&&(n.commentLine=!1)}}}}]);