"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["9301"],{33081(e,t,r){r.r(t),r.d(t,{default:()=>c});var n=r(78385),o=r(30761);let a="jp-mod-searchable",c=[{id:"@jupyter-notebook/documentsearch-extension:notebookShellWidgetListener",requires:[o.INotebookShell,n.ISearchProviderRegistry],autoStart:!0,description:"A plugin to add document search functionalities",activate:(e,t,r)=>{let n=e=>{e&&(r.hasProvider(e)?e.addClass(a):e.removeClass(a))};r.changed.connect(()=>n(t.currentWidget)),t.currentChanged.connect((e,r)=>{t.currentWidget&&n(t.currentWidget)})}}]}}]);