"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["167"],{84202(e,a,t){t.d(a,{diagram:()=>g});var r=t(13670),n=t(23345),d=t(87724),s=t(11150),i={parse:(0,d.K2)(async e=>{let a=await (0,s.qg)("info",e);d.Rm.debug(a)},"parse")},p=(0,d.K2)(()=>"11.13.0","getVersion"),g={parser:i,db:{getVersion:p},renderer:{draw:(0,d.K2)((e,a,t)=>{d.Rm.debug("rendering info diagram\n"+e);let s=(0,r.D)(a);(0,n.a$)(s,100,400,!0),s.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${t}`)},"draw")}}}}]);