"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["533"],{73076(r,t,n){function u(r,t){return r.skipToEnd(),t.cur=s,"error"}function e(r,t){return r.match(/^HTTP\/\d\.\d/)?(t.cur=c,"keyword"):r.match(/^[A-Z]+/)&&/[ \t]/.test(r.peek())?(t.cur=i,"keyword"):u(r,t)}function c(r,t){var n=r.match(/^\d+/);if(!n)return u(r,t);t.cur=o;var e=Number(n[0]);return e>=100&&e<400?"atom":"error"}function o(r,t){return r.skipToEnd(),t.cur=s,null}function i(r,t){return r.eatWhile(/\S/),t.cur=a,"string.special"}function a(r,t){return r.match(/^HTTP\/\d\.\d$/)?(t.cur=s,"keyword"):u(r,t)}function s(r){return!r.sol()||r.eat(/[ \t]/)?(r.skipToEnd(),"string"):r.match(/^.*?:/)?"atom":(r.skipToEnd(),"error")}function k(r){return r.skipToEnd(),null}n.d(t,{http:()=>T});let T={name:"http",token:function(r,t){var n=t.cur;return n!=s&&n!=k&&r.eatSpace()?null:n(r,t)},blankLine:function(r){r.cur=k},startState:function(){return{cur:e}}}}}]);