"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["2320"],{46051(e,t,o){o.r(t),o.d(t,{default:()=>b});var a,n,r=o(37210),l=o(96097),u=o(6193),p=o(62483),s=o(38550);let c=[{text:"About Jupyter",url:"https://jupyter.org"},{text:"Markdown Reference",url:"https://commonmark.org/help/"},{text:"Documentation",url:"https://jupyter-notebook.readthedocs.io/en/stable/"}];(a=n||(n={})).open="help:open",a.about="help:about";let b=[{id:"@jupyter-notebook/help-extension:open",autoStart:!0,description:"A plugin to open the about section with resources",activate:e=>{let{commands:t}=e;t.addCommand(n.open,{label:e=>e.text,execute:e=>{let t=e.url;!function(e){try{let t=new URL(e,window.location.href).protocol.toLowerCase();return["http:","https:","mailto:"].includes(t)}catch(e){return!1}}(t)?console.warn(`Blocked unsafe URL: ${t}`):window.open(t)},describedBy:{args:{type:"object",properties:{text:{type:"string",description:"The label to display for the help resource."},url:{type:"string",description:"The URL to open in a new browser tab."}},required:["text","url"]}}})}},{id:"@jupyter-notebook/help-extension:about",autoStart:!0,requires:[u.ITranslator],optional:[l.IMainMenu,r.ICommandPalette],description:"Plugin to add a command to show an About Jupyter Notebook and Markdown Reference",activate:(e,t,o,a)=>{let{commands:l}=e,u=t.load("notebook"),b=u.__("Help");l.addCommand(n.about,{label:u.__("About %1",e.name),execute:()=>{let t=s.createElement(s.Fragment,null,s.createElement("span",{className:"jp-AboutNotebook-header"},s.createElement(p.jupyterIcon.react,{width:"196px",height:"auto"}))),o=u.__("JUPYTER NOTEBOOK ON GITHUB"),a=u.__("CONTRIBUTOR LIST"),n=s.createElement("span",null,s.createElement("a",{href:"https://github.com/jupyter/notebook",target:"_blank",rel:"noopener noreferrer",className:"jp-Button-flat jp-AboutNotebook-about-externalLinks"},o),s.createElement("a",{href:"https://github.com/jupyter/notebook/pulse",target:"_blank",rel:"noopener noreferrer",className:"jp-Button-flat jp-AboutNotebook-about-externalLinks"},a)),l=u.__("Version: %1",e.version),c=u.__("\xa9 2021-2025 Jupyter Notebook Contributors"),b=s.createElement(s.Fragment,null,s.createElement("span",{className:"jp-AboutNotebook-version"},l),s.createElement("div",null,n),s.createElement("span",{className:"jp-AboutNotebook-about-copyright"},c)),i=new r.Dialog({title:t,body:b,buttons:[r.Dialog.createButton({label:u.__("Dismiss"),className:"jp-AboutNotebook-about-button jp-mod-reject jp-mod-styled"})]});i.addClass("jp-AboutNotebook"),i.launch()},describedBy:{args:{type:"object",properties:{}}}}),a&&a.addItem({command:n.about,category:b});let i=c.map(e=>({args:e,command:n.open}));o&&o.helpMenu.addGroup(i,30)}}]}}]);