"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["5395"],{95328(e,a,r){r.d(a,{K:()=>s});var l=Object.defineProperty,s=(e,a)=>l(e,"name",{value:a,configurable:!0})},36222(e,a,r){r.r(a),r.d(a,{default:()=>s});var l=(0,r(95328).K)(async()=>await Promise.all([r.e("7103"),r.e("2715"),r.e("4680")]).then(r.bind(r,28667)),"loader"),s=[{name:"elk",loader:l,algorithm:"elk.layered"},...["elk.stress","elk.force","elk.mrtree","elk.sporeOverlap"].map(e=>({name:e,loader:l,algorithm:e}))]}}]);