"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["4959"],{69426(e,t,n){var r;function a(e,t){var n,l=e.next();if("<"==l&&e.eat("!")){if(e.eatWhile(/[\-]/))return t.tokenize=u,u(e,t);else if(e.eatWhile(/[\w]/))return r="doindent","keyword"}else if("<"==l&&e.eat("?"))return t.tokenize=function(e,t){for(;!e.eol();){if(e.match("?>")){t.tokenize=a;break}e.next()}return"meta"},r=l,"meta";else if("#"==l&&e.eatWhile(/[\w]/))return r="tag","atom";else if("|"==l)return r="separator","keyword";else if(l.match(/[\(\)\[\]\-\.,\+\?>]/))return r=l,null;else if(l.match(/[\[\]]/))return r=l,"rule";else if('"'==l||"'"==l){return n=l,t.tokenize=function(e,t){for(var u,l=!1;null!=(u=e.next());){if(u==n&&!l){t.tokenize=a;break}l=!l&&"\\"==u}return r="tag","string"},t.tokenize(e,t)}else{if(!e.eatWhile(/[a-zA-Z\?\+\d]/))return"%"==l||"*"==l?(r="number","number"):(e.eatWhile(/[\w\\\-_%.{,]/),r=null,null);var s=e.current();return null!==s.substr(s.length-1,s.length).match(/\?|\+/)&&e.backUp(1),r="tag","tag"}}function u(e,t){for(var n,u=0;null!=(n=e.next());){if(u>=2&&">"==n){t.tokenize=a;break}u="-"==n?u+1:0}return r="comment","comment"}n.d(t,{dtd:()=>l});let l={name:"dtd",startState:function(){return{tokenize:a,baseIndent:0,stack:[]}},token:function(e,t){if(e.eatSpace())return null;var n=t.tokenize(e,t),a=t.stack[t.stack.length-1];return"["==e.current()||"doindent"===r||"["==r?t.stack.push("rule"):"endtag"===r?t.stack[t.stack.length-1]="endtag":"]"==e.current()||"]"==r||">"==r&&"rule"==a?t.stack.pop():"["==r&&t.stack.push("["),n},indent:function(e,t,n){var a=e.stack.length;return"]"===t.charAt(0)?a--:">"===t.substr(t.length-1,t.length)&&("<"===t.substr(0,1)||"doindent"==r&&t.length>1||("doindent"==r?a--:">"==r&&t.length>1||"tag"==r&&">"!==t||("tag"==r&&"rule"==e.stack[e.stack.length-1]?a--:"tag"==r?a++:">"===t&&"rule"==e.stack[e.stack.length-1]&&">"===r?a--:">"===t&&"rule"==e.stack[e.stack.length-1]||("<"!==t.substr(0,1)&&">"===t.substr(0,1)?a-=1:">"===t||(a-=1)))),(null==r||"]"==r)&&a--),e.baseIndent+a*n.unit},languageData:{indentOnInput:/^\s*[\]>]$/}}}}]);