"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["6899"],{47907(e,t,r){r.r(t),r.d(t,{INotebookTree:()=>T,NotebookTreeWidget:()=>s});var o=r(93169),a=r(56820);class s extends a.TabPanel{constructor(){super({tabPlacement:"top",tabsMovable:!0,renderer:o.TabBarSvg.defaultRenderer}),this.addClass("jp-TreePanel")}}let T=new(r(83044)).Token("@jupyter-notebook/tree:INotebookTree")}}]);