"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([["4011"],{25270(t,e,r){function a(t){var e=t.match(/^\s*\S/);return t.skipToEnd(),e?"error":null}r.d(e,{asciiArmor:()=>s});let s={name:"asciiarmor",token:function(t,e){var r;if("top"==e.state)return t.sol()&&(r=t.match(/^-----BEGIN (.*)?-----\s*$/))?(e.state="headers",e.type=r[1],"tag"):a(t);if("headers"==e.state)if(t.sol()&&t.match(/^\w+:/))return e.state="header","atom";else{var s=a(t);return s&&(e.state="body"),s}if("header"==e.state)return t.skipToEnd(),e.state="headers","string";if("body"==e.state)if(t.sol()&&(r=t.match(/^-----END (.*)?-----\s*$/)))return r[1]!=e.type?"error":(e.state="end","tag");else return t.eatWhile(/[A-Za-z0-9+\/=]/)?null:(t.next(),"error");if("end"==e.state)return a(t)},blankLine:function(t){"headers"==t.state&&(t.state="body")},startState:function(){return{state:"top",type:null}}}}}]);